@@ -1,5 +1,5 @@
 /*
-    htpdate v1.3.6
+    htpdate v1.3.7
 
     Eddy Vervest <eddy@vervest.org>
     http://www.vervest.org/htp
@@ -61,7 +61,7 @@
 #include <openssl/ssl.h>
 #endif
 
-#define VERSION                  "1.3.6"
+#define VERSION                  "1.3.7"
 #define MAX_HTTP_HOSTS           16                /* 16 web servers */
 #define DEFAULT_HTTP_PORT        "80"
 #define DEFAULT_PROXY_PORT       "8080"
@@ -126,7 +126,6 @@ static void splitURL(char **scheme, char **host, char **port, char **path) {
 
     *path = "";
     *scheme = NULL;
-    *port = DEFAULT_HTTP_PORT;
 
     if ((ps = strcasestr(*host, "https://")) != NULL) {
         #ifndef ENABLE_HTTPS
@@ -355,6 +354,7 @@ static double getHTTPdate(
     SSL_CTX_set_verify_depth(tls_ctx, 4);
     if (verifycert) SSL_CTX_set_verify(tls_ctx, SSL_VERIFY_PEER, NULL);
     SSL *conn = SSL_new(tls_ctx);
+    SSL_set_tlsext_host_name(conn, host);
     if (scheme) {
         if (proxy) {
             rc = proxyCONNECT(server_s, host, port, proxy, proxyport, httpversion);
@@ -826,8 +826,9 @@ int main(int argc, char *argv[]) {
             }
             break;
         case 'P':
-            proxy = (char *)optarg;
             proxyport = DEFAULT_PROXY_PORT;
+            char *proxywithport = strdup((char *)optarg);
+            proxy = proxywithport;
             splitURL(&scheme, &proxy, &proxyport, &path);
             break;
         case '?':
@@ -857,6 +858,7 @@ int main(int argc, char *argv[]) {
         }
         if (debug) printlog(0, "Proxy: %s", proxy);
         proxy += 7;
+        proxyport = DEFAULT_PROXY_PORT;
         splitURL(&scheme, &proxy, &proxyport, &path);
     }
 
@@ -900,6 +902,7 @@ int main(int argc, char *argv[]) {
             /* host:port is stored in argv[i] */
             char *hostport = strdup(argv[i]);
             host = hostport;
+            port = DEFAULT_HTTP_PORT;
             splitURL(&scheme, &host, &port, &path);
 
             double offset = getHTTPdate(scheme, host, port, path,
@@ -938,6 +941,9 @@ int main(int argc, char *argv[]) {
 
             timeavg = sumtimes / goodtimes;
 
+            /* Avoid bouncing between upper/lower limit when (almost) in sync */
+            if (timeavg < 1 && timeavg > -1) timeavg /= 2;
+
             if (debug > 1)
                 printlog(0, "#: %d, mean: %.3f, average: %.3f", goodtimes, mean, timeavg);
 
